@@ -53,7 +53,7 @@ web:xmpp #de'''
         # handle single and double quotes
         term = term.replace("'",'"')
 
-        query = 'select title,url,date '
+        query = 'select title,url,date, abstract '
         query += 'from search.web where query=\'%s\' ' % term
 
         if lang:
@@ -83,7 +83,7 @@ web:xmpp #de'''
         # handle single and double quotes
         term = term.replace("'",'"')
 
-        query = 'select title,url,date '
+        query = 'select title,url, date, abstract '
         query += 'from search.news where query=\'%s\' ' % term
 
         if lang:
@@ -168,4 +168,4 @@ web:xmpp #de'''
                 result += '<a href="%s">%s</a><br/>' % (xmlify(row['url']), title)
         else:
             result +='No blips found!'
-        return result
\ No newline at end of file
+        return result
